use chrono::{DateTime, FixedOffset, Local, Utc};
use serde::Serialize;
use sqlx::{prelude::FromRow, Decode, Encode};
use uuid::Uuid;

#[derive(Decode, Serialize, FromRow)]
pub struct Chat {
    // Uuid but sqlx doesnt impl serde traits for them
    pub id: Uuid,
    pub url_path: String,
    pub name: Option<String>,
}

#[derive(Decode, Serialize, FromRow)]
pub struct Message {
    // Uuid but sqlx doesnt impl serde traits for them
    pub id: Uuid,
    pub chat_id: Uuid,
    pub timestamp: DateTime<Utc>,

    pub content: String,
    pub from_admin: bool,
}

#[derive(Encode)]
pub struct NewChat {
    url_path: String,
    name: Option<String>,
}

#[derive(Encode)]
pub struct NewMessage {
    chat_id: Uuid,
    content: String,
    from_admin: bool,
}
